# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (c) 2010, 2degrees Limited.
# All Rights Reserved.
#
# This file is part of Djangout: <http://bitbucket.org/2degrees/djangout>.
#
# Djangout is subject to the provisions of the BSD license that accompanies
# that distribution. An incomplete copy of that text is also available at
# <http://dev.2degreesnetwork.com/p/2degrees-license.html>. THIS SOFTWARE IS
# PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF TITLE,
# MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
#
################################################################################
"""
Buildout recipes for Buildout.

"""
from os import path
from logging import getLogger

from pkg_resources import working_set
from zc.recipe.egg import Eggs

_LOGGER = getLogger(__name__)


class AdminMediaRecipe(object):
    """
    Recipe to make available the path to the media files in Django Admin.
    
    """
    
    def __init__(self, buildout, name, options):
        if "eggs" not in options:
            # If we don't set the "eggs" option, it will take the part name:
            options['eggs'] = ""
            _LOGGER.debug("Set the 'eggs' option to an empty string")
        ws = Eggs(buildout, name, options).working_set(["django >= 1.0"])[1]
        for dist in ws:
            working_set.add(dist)
        
        # Finding the path to the media in Django Admin:
        from django import __file__ as django_file
        django_root = path.dirname(django_file)
        admin_media = path.join(django_root, "contrib", "admin", "media")
        # We found it, let's make it available to other recipes/parts:
        options['admin_media_root'] = admin_media
    
    def install(self):
        return ()
    
    def update(self):
        return ()



# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (c) 2010, 2degrees Limited.
# All Rights Reserved.
#
# This file is part of Djangout: <http://bitbucket.org/2degrees/djangout>.
#
# Djangout is subject to the provisions of the BSD license that accompanies
# that distribution. An incomplete copy of that text is also available at
# <http://dev.2degreesnetwork.com/p/2degrees-license.html>. THIS SOFTWARE IS
# PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF TITLE,
# MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
#
################################################################################
import os

# Setuptools is obviously available, so there's no need to use ez_setup:
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, "README.txt")).read()
CHANGELOG = open(os.path.join(here, "docs", "source", "changelog.rst")).read()
version = open(os.path.join(here, "VERSION.txt")).readline().rstrip()

setup(name="djangout",
      version=version,
      description="Buildout recipes for Django",
      long_description="\n".join((README, CHANGELOG)),
      classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Buildout",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2",
        "Topic :: Internet :: WWW/HTTP",
        ],
      keywords="buildout recipe django media",
      author="2degrees Limited",
      author_email="2degrees-dev@googlegroups.com",
      url="http://bitbucket.org/2degrees/djangout/",
      license="BSD (http://dev.2degreesnetwork.com/p/2degrees-license.html)",
      py_modules=["djangout"],
      package_data={
        '': ["VERSION.txt", "README.txt"],
        'docs': ["Makefile", "source/*"],
        },
      exclude_package_data={"": ["README.txt", "docs"]},
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        "zc.buildout >= 1.4.0",
        "zc.recipe.egg >= 1.1.0",
        "Django >= 1.0",
        ],
      entry_points = """\
        [zc.buildout]
        admin_media = djangout:AdminMediaRecipe
      """
      )
